LedgerLog

Struct LedgerLog 

pub(crate) struct LedgerLog<T: Serialize + DeserializeOwned> {
    cache_start: usize,
    cache_size: usize,
    cache: VecDeque<Option<T>>,
    store: AppendLog<BincodeLoadStore<Option<T>>>,
    pending_inserts: usize,
    missing: usize,
}
A caching append log for ledger objects.

Fields

cache_start: usizecache_size: usizecache: VecDeque<Option<T>>store: AppendLog<BincodeLoadStore<Option<T>>>pending_inserts: usizemissing: usize

Implementations

Source

impl<T: Serialize + DeserializeOwned + Clone> LedgerLog<T>

pub(crate) fn create( loader: &mut AtomicStoreLoader, file_pattern: &str, cache_size: usize, ) -> Result<Self, PersistenceError>

pub(crate) fn open( loader: &mut AtomicStoreLoader, file_pattern: &str, cache_size: usize, ) -> Result<Self, PersistenceError>

pub(crate) fn iter(&self) -> Iter<'_, T>

pub(crate) fn store_resource( &mut self, resource: Option<T>, ) -> Result<(), PersistenceError>

pub(crate) fn insert( &mut self, index: usize, object: T, ) -> Result<bool, PersistenceError>
where T: Debug,

Insert an object at position index.

Returns whether the object was newly inserted; that is, returns false if and only if there was already an object present at this index.

pub(crate) async fn commit_version(&mut self) -> Result<(), PersistenceError>

pub(crate) fn skip_version(&mut self) -> Result<(), PersistenceError>

pub(crate) fn revert_version(&mut self) -> Result<(), PersistenceError>

pub(crate) fn sync_status( &self, start: usize, end: usize, is_missing: impl Fn(&T) -> bool, ) -> ResourceSyncStatus

Find the sync status of this resource.

This function will find all consecutive ranges of a given SyncStatus in [0, block_height). The predicate is_missing can be used to consider an object missing even if there is actually an object present in the database (for example if some field is None).